/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 04099
 |         NATIONAL SURVEY OF SUBSTANCE ABUSE TREATMENT SERVICES
 |                            (N-SSATS), 2003
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\04099-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE mode      1='(1) Phone' 2='(2) Mail' 9='(9) Web' ;
  VALUE stfips    1='(01) ALABAMA' 2='(02) ALASKA' 4='(04) ARIZONA'
                  5='(05) ARKANSAS' 6='(06) CALIFORNIA' 8='(08) COLORADO'
                  9='(09) CONNECTICUT' 10='(10) DELAWARE'
                  11='(11) DIST OF COLUMBIA' 12='(12) FLORIDA'
                  13='(13) GEORGIA' 15='(15) HAWAII' 16='(16) IDAHO'
                  17='(17) ILLINOIS' 18='(18) INDIANA' 19='(19) IOWA'
                  20='(20) KANSAS' 21='(21) KENTUCKY' 22='(22) LOUISIANA'
                  23='(23) MAINE' 24='(24) MARYLAND' 25='(25) MASSACHUSETTS'
                  26='(26) MICHIGAN' 27='(27) MINNESOTA'
                  28='(28) MISSISSIPPI' 29='(29) MISSOURI' 30='(30) MONTANA'
                  31='(31) NEBRASKA' 32='(32) NEVADA' 33='(33) NEW HAMPSHIRE'
                  34='(34) NEW JERSEY' 35='(35) NEW MEXICO'
                  36='(36) NEW YORK' 37='(37) NORTH CAROLINA'
                  38='(38) NORTH DAKOTA' 39='(39) OHIO' 40='(40) OKLAHOMA'
                  41='(41) OREGON' 42='(42) PENNSYLVANIA'
                  44='(44) RHODE ISLAND' 45='(45) SOUTH CAROLINA'
                  46='(46) SOUTH DAKOTA' 47='(47) TENNESSEE' 48='(48) TEXAS'
                  49='(49) UTAH' 50='(50) VERMONT' 51='(51) VIRGINIA'
                  53='(53) WASHINGTON' 54='(54) WEST VIRGINIA'
                  55='(55) WISCONSIN' 56='(56) WYOMING'
                  60='(60) AMERICAN SAMOA' 64='(64) FED MICRONESIA'
                  66='(66) GUAM' 70='(70) PALAU' 72='(72) PUERTO RICO'
                  78='(78) VIRGIN ISLANDS' ;
  VALUE region    0='(0) US Jurisdiction/Territory' 1='(1) Northeast'
                  2='(2) Midwest' 3='(3) South' 4='(4) West' ;
  VALUE division  0='(0) US Jurisdiction/Territory' 1='(1) New England'
                  2='(2) Mid-Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central'
                  8='(8) Mountain' 9='(9) Pacific' ;
  VALUE othnontx  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE detox     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatmt   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE loc5ffff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE admin     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE focus     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Substance abuse treatment services'
                  2='(2) Mental health services'
                  3='(3) Mix of mental health and substance abuse'
                  4='(4) General health care' 5='(5) Other' ;
  VALUE ownershp  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Private for-profit organization'
                  2='(2) Private non-profit organization'
                  3='(3) State government'
                  4='(4) Local, county, or community government'
                  5='(5) Tribal government' 6='(6) Federal government' ;
  VALUE fedown    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Department of Veterans Affairs'
                  2='(2) Department of Defense' 3='(3) Indian Health Service'
                  4='(4) Other' ;
  VALUE loc15fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE relig     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE hospital  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE locs      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) General hospital (including VA)'
                  2='(2) Psychiatric hospital'
                  3='(3) Other specialty hospital' ;
  VALUE hotyn     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc27ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc70ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc71ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc72ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc73ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc74ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc36ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc37ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc38ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc39ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc49ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc50ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc52ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc24ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc55ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc59ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc48ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc75ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE otp       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE otptype   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Maintenance program' 2='(2) Detoxification program'
                  3='(3) Both' ;
  VALUE otpall    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE dui_dwi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE onlydui   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE signlang  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang3fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang9fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang12ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang13ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang17ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang18ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' 2='(2) Yes, via interpreter'
                  3='(3) Yes, via telephone service' ;
  VALUE srvc76ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc30ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc77ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc31ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc78ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc61ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc79ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc32ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc80ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc62ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc81ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc63ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc82ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc33ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc83ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc34ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc84ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc64ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc35ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype4ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypehif  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeh0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypercf  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctyper0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctyper1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeml   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE feescale  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE payasst   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk8f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk5f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk4f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk2a  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE earmark   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE writarra  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE sat       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE type4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clihi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE h_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE himetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE hilamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE hospbed   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli9ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli10f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clirc   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE r_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rcmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rclamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE resbed    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climl   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli8ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli5ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cliop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE o_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE opmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE oplamnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE b_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE a_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE d_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE totadmis  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE faccli    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Only this facility'
                  2='(2) This facility plus others' ;
  VALUE facnum    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE acthi     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE actres    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE actop     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE totadest  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE licensed  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenmh   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenph   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenhos  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE jcaho     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE carf      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ncqa      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE coa       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othstate  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE internet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE hasweb    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE rptlvl    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Reporting for self'
                  2='(2) Reporting for self and others'
                  3='(3) Client counts reported by another facility' ;
  VALUE t_cli11f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clijuv  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE ownrspfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE otpfl     0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE otptypef  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE otpallfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE langfl    0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE othfac0f  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE othfac4f  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE type4fl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_clihif  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE himtlamf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE hospbedf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE type7fl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_clircf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE rcmtlamf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE resbedfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE type1fl   0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE t_cliopf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE opmtlamf  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE pctfl     0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE totadmfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE facnumfl  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=544;
INPUT
        CASEID 1-5              MODE 6                  STFIPS 7-8
        REGION 9                DIVISION 10             OTHNONTX 11-13
        DETOX 14-16             TREATMT 17-19           LOC5 20-22
        ADMIN 23-25             FOCUS 26-28             OWNERSHP 29-31
        FEDOWN 32-34            LOC15 35-37             RELIG 38-40
        HOSPITAL 41-43          LOCS 44-46              HOTYN 47-49
        SRVC1 50-52             SRVC2 53-55             SRVC4 56-58
        SRVC5 59-61             SRVC6 62-64             SRVC8 65-67
        SRVC27 68-70            SRVC70 71-73            SRVC71 74-76
        SRVC72 77-79            SRVC10 80-82            SRVC11 83-85
        SRVC73 86-88            SRVC74 89-91            SRVC14 92-94
        SRVC15 95-97            SRVC16 98-100           SRVC36 101-103
        SRVC37 104-106          SRVC38 107-109          SRVC39 110-112
        SRVC49 113-115          SRVC50 116-118          SRVC52 119-121
        SRVC24 122-124          SRVC55 125-127          SRVC59 128-130
        SRVC48 131-133          SRVC75 134-136          OTP 137-139
        OTPTYPE 140-142         OTPALL 143-145          DUI_DWI 146-148
        ONLYDUI 149-151         SIGNLANG 152-154        LANG 155-157
        LANG1 158-160           LANG2 161-163           LANG3 164-166
        LANG4 167-169           LANG5 170-172           LANG6 173-175
        LANG7 176-178           LANG8 179-181           LANG9 182-184
        LANG10 185-187          LANG11 188-190          LANG12 191-193
        LANG13 194-196          LANG14 197-199          LANG15 200-202
        LANG16 203-205          LANG17 206-208          LANG18 209-211
        SRVC76 212-214          SRVC30 215-217          SRVC77 218-220
        SRVC31 221-223          SRVC78 224-226          SRVC61 227-229
        SRVC79 230-232          SRVC32 233-235          SRVC80 236-238
        SRVC62 239-241          SRVC81 242-244          SRVC63 245-247
        SRVC82 248-250          SRVC33 251-253          SRVC83 254-256
        SRVC34 257-259          SRVC84 260-262          SRVC64 263-265
        SRVC35 266-268          CTYPE4 269-271          CTYPEHI1 272-274
        CTYPEHI2 275-277        CTYPE7 278-280          CTYPERC1 281-283
        CTYPERC3 284-286        CTYPERC4 287-289        CTYPE1 290-292
        CTYPE6 293-295          CTYPEML 296-298         CTYPEOP 299-301
        CTYPE2 302-304          CTYPE3 305-307          FEESCALE 308-310
        PAYASST 311-313         REVCHK1 314-316         REVCHK8 317-319
        REVCHK5 320-322         REVCHK10 323-325        REVCHK15 326-328
        REVCHK2 329-331         REVCHK3 332-334         REVCHK2A 335-337
        EARMARK 338-340         WRITARRA 341-343        SAT 344-346
        OTHFAC2 347-349         OTHFAC1 350-352         OTHFAC3 353-355
        TYPE4 356-358           T_CLI1 359-361          T_CLI2 362-364
        T_CLIHI 365-367         H_AGE1 368-370          HIMETNUM 371-373
        HILAMNUM 374-376        HOSPBED 377-379         TYPE7 380-382
        T_CLI3 383-386          T_CLI9 387-389          T_CLI10 390-392
        T_CLIRC 393-396         R_AGE1 397-399          RCMETNUM 400-402
        RCLAMNUM 403-405        RESBED 406-408          TYPE1 409-411
        T_CLI7 412-414          T_CLIML 415-418         T_CLI8 419-422
        T_CLI6 423-426          T_CLI5 427-430          T_CLIOP 431-434
        O_AGE1 435-437          OPMETNUM 438-441        OPLAMNUM 442-444
        B_PCT 445-447           A_PCT 448-450           D_PCT 451-453
        TOTADMIS 454-458        FACCLI 459-461          FACNUM 462-464
        ACTHI 465-467           ACTRES 468-470          ACTOP 471-473
        TOTADEST 474-476        LICENSED 477-479        LICENMH 480-482
        LICENPH 483-485         LICENHOS 486-488        JCAHO 489-491
        CARF 492-494            NCQA 495-497            COA 498-500
        OTHSTATE 501-503        INTERNET 504-506        HASWEB 507-509
        RPTLVL 510-512          T_CLI11 513-516         T_CLIJUV 517-519
        T_CLIMET 520-523        OWNRSPFL 524            OTPFL 525
        OTPTYPEF 526            OTPALLFL 527            LANGFL 528
        OTHFAC2F 529            OTHFAC1F 530            TYPE4FL 531
        T_CLIHIF 532            HIMTLAMF 533            HOSPBEDF 534
        TYPE7FL 535             T_CLIRCF 536            RCMTLAMF 537
        RESBEDFL 538            TYPE1FL 539             T_CLIOPF 540
        OPMTLAMF 541            PCTFL 542               TOTADMFL 543
        FACNUMFL 544            ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'Case Identification Number' 
   MODE    = 'Control: Completes 1=phone 2=mail 9=web' 
   STFIPS  = 'Census State FIPS codes label' 
   REGION  = 'Added: Census Region' 
   DIVISION= 'Added: Census Division' 
   OTHNONTX= 'Offered Intake/Ass''mnt/Refer''l 3/31/03' 
   DETOX   = 'Offered Detox 3/31/03' 
   TREATMT = 'Offered SA Tx 3/31/03' 
   LOC5    = 'Setting, Halfway House' 
   ADMIN   = 'Offered Other SA Services such as admin 3/31/03' 
   FOCUS   = 'Primary focus SA Tx/MH/Mix/GH' 
   OWNERSHP= 'Ownership' 
   FEDOWN  = 'Federal Government Agency' 
   LOC15   = 'Solo practice' 
   RELIG   = 'Affiliated w/ religious organization' 
   HOSPITAL= 'Located in/operated by hospital' 
   LOCS    = 'Hospital Type' 
   HOTYN   = 'Hotline - yes/no' 
   SRVC1   = 'Assessment comprehensive SA' 
   SRVC2   = 'Assessment  mental health' 
   SRVC4   = 'Therapy family counseling' 
   SRVC5   = 'Therapy group' 
   SRVC6   = 'Therapy individual' 
   SRVC8   = 'Therapy relapse prevention' 
   SRVC27  = 'Therapy aftercare counseling' 
   SRVC70  = 'Pharmacotherapies Antabase' 
   SRVC71  = 'Pharmacotherapies Naltrexone' 
   SRVC72  = 'Pharmacotherapies Buprenorphine' 
   SRVC10  = 'Testing blood/alcohol' 
   SRVC11  = 'Testing drug/alcohol urine screen' 
   SRVC73  = 'Testing Hepatitis B' 
   SRVC74  = 'Testing Hepatitis C' 
   SRVC14  = 'Testing HIV' 
   SRVC15  = 'Testing STD' 
   SRVC16  = 'Testing TB screen' 
   SRVC36  = 'Transitional Assist. Social Services' 
   SRVC37  = 'Transitional Discharge Plan' 
   SRVC38  = 'Transitional Employment' 
   SRVC39  = 'Transitional Housing Assist' 
   SRVC49  = 'Other Services Case Management' 
   SRVC50  = 'Other Child Care' 
   SRVC52  = 'Other Domestic Violence' 
   SRVC24  = 'Other HIV/AIDS Edu' 
   SRVC55  = 'Other Outcome Follow-Up' 
   SRVC59  = 'Other Transportation Assistance' 
   SRVC48  = 'Other Acupuncture' 
   SRVC75  = 'Residential Beds for Client''s children' 
   OTP     = 'Operate an Opioid Treatment Program' 
   OTPTYPE = 'OTP for maintenance/detoxification/both' 
   OTPALL  = 'All clients in OTP' 
   DUI_DWI = 'Program for DUI/DWI/other offenders' 
   ONLYDUI = 'All SA Tx clients DUI/DWI' 
   SIGNLANG= 'Tx in sign language-y/n' 
   LANG    = 'Tx in language other than English-y/n' 
   LANG1   = 'Tx in Hopi' 
   LANG2   = 'Tx in Lakota' 
   LANG3   = 'Tx in Navajo' 
   LANG4   = 'Tx in Yupik' 
   LANG5   = 'Tx in Other American Indian/Alaska Native' 
   LANG6   = 'Tx in Arabic' 
   LANG7   = 'Tx in Chinese' 
   LANG8   = 'Tx in Creole' 
   LANG9   = 'Tx in French' 
   LANG10  = 'Tx in German' 
   LANG11  = 'Tx in Hmong' 
   LANG12  = 'Tx in Korean' 
   LANG13  = 'Tx in Polish' 
   LANG14  = 'Tx in Portuguese' 
   LANG15  = 'Tx in Russian' 
   LANG16  = 'Tx in Spanish' 
   LANG17  = 'Tx in Vietnamese' 
   LANG18  = 'Tx in Other Language' 
   SRVC76  = 'Accepts adolescents' 
   SRVC30  = 'Specific Program/gr''p for adolescents' 
   SRVC77  = 'Accepts co-occurring' 
   SRVC31  = 'Specific Program/gr''p for co-occurring' 
   SRVC78  = 'Accepts crimn''l justice clients' 
   SRVC61  = 'Specific Program/gr''p for crimn''l justice clients' 
   SRVC79  = 'Accepts persons with HIV/AIDS' 
   SRVC32  = 'Specific Program/gr''p for persons with HIV/AIDS' 
   SRVC80  = 'Accepts gays/lesbians' 
   SRVC62  = 'Specific Program/gr''p for gays/lesbians' 
   SRVC81  = 'Accepts seniors' 
   SRVC63  = 'Specific Program/gr''p for seniors' 
   SRVC82  = 'Accepts preg''t/postpart''m women' 
   SRVC33  = 'Specific Program/gr''p for preg''t/postpart''m women' 
   SRVC83  = 'Accepts women' 
   SRVC34  = 'Specific Program/gr''p for women' 
   SRVC84  = 'Accepts men' 
   SRVC64  = 'Specific Program/gr''p for men' 
   SRVC35  = 'Specific Program/gr''p for other groups' 
   CTYPE4  = 'Hosp Inpat''nt SA care offered currently' 
   CTYPEHI1= 'Hosp Inpat''nt Detoxification care offered' 
   CTYPEHI2= 'Hosp Inpat''nt Rehabilitation care offered' 
   CTYPE7  = 'Non-hosp Res SA care offered currently' 
   CTYPERC1= 'Non-hosp Res Detoxification care offered' 
   CTYPERC3= 'Non-hosp Res Short Term Tx' 
   CTYPERC4= 'Non-hosp Res Long Term Tx' 
   CTYPE1  = 'Any Outpat''nt SA care offered currently' 
   CTYPE6  = 'Outpat''nt Detox offered currently' 
   CTYPEML = 'Outpat''nt meth/LAAM maint. offered' 
   CTYPEOP = 'Day Tx/Partial Hosp offered currently' 
   CTYPE2  = 'Intensive Outpat''nt offered currently' 
   CTYPE3  = 'Regular Outpat''nt offered currently' 
   FEESCALE= 'Uses  sliding fee scale' 
   PAYASST = 'Offers other payment assistance' 
   REVCHK1 = 'Accepts cash or self-payment' 
   REVCHK8 = 'Accepts Medicare payments' 
   REVCHK5 = 'Accepts Medicaid payments' 
   REVCHK10= 'Accepts state financed health ins' 
   REVCHK15= 'Accepts Federal military insurance' 
   REVCHK2 = 'Accepts Private Health insurance' 
   REVCHK3 = 'Accepts Free Tx to all Clients' 
   REVCHK2A= 'Accepts other payments' 
   EARMARK = 'Receive any Fed,State,C''nty,Local Funds' 
   WRITARRA= 'Agrmnts/contrs w/Mang''d Care Org' 
   SAT     = 'Provide SA Tx or Detox on 3/31/03' 
   OTHFAC2 = 'Client counts-This Facility Only' 
   OTHFAC1 = 'Client counts-Fac Combined w/Others' 
   OTHFAC3 = 'Cannot Provide Any Client Counts' 
   TYPE4   = 'Hosp Inpat''nt SA care offered 3/31/03' 
   T_CLI1  = 'Hosp. Inpatient clients, detox' 
   T_CLI2  = 'Hosp. Inpatient clients, Tx' 
   T_CLIHI = 'Total Number of Hospital Inpatients' 
   H_AGE1  = 'Hosp Inp Clients Under 18 years old' 
   HIMETNUM= 'Total Methadone Inpatients' 
   HILAMNUM= 'Total LAAM Inpatients' 
   HOSPBED = 'Total Beds Designated-Hospital Inpatient' 
   TYPE7   = 'Non-hosp Res SA care offered 3/31/03' 
   T_CLI3  = 'Residential Clients, Detox' 
   T_CLI9  = 'Residential Clients, Short-term Tx' 
   T_CLI10 = 'Residential Clients, Long-term Tx' 
   T_CLIRC = 'Total Residential Clients' 
   R_AGE1  = 'Residential Clients Under 18 years old' 
   RCMETNUM= 'Total Methadone Residential' 
   RCLAMNUM= 'Total LAAM Residential' 
   RESBED  = 'Total Beds-Residential Clients' 
   TYPE1   = 'Any clients rec''vd Outpat''nt care, 3/31/03' 
   T_CLI7  = 'Clients in Outpat''nt detox' 
   T_CLIML = 'Clients in Outpat''nt meth/LAAM Treat.' 
   T_CLI8  = 'Clients in Day Tx/Partial Hosp' 
   T_CLI6  = 'Clients in Intensive Outpat''nt' 
   T_CLI5  = 'Clients in regular Outpat''nt Care' 
   T_CLIOP = 'Total Number of Outpat''nt Clients' 
   O_AGE1  = 'Outpat''nt clients under 18 years old' 
   OPMETNUM= 'Total Methadone Outpat''nts' 
   OPLAMNUM= 'Total LAAM Outpat''nts' 
   B_PCT   = '% of Clients Treated for Alc/Drug Abuse' 
   A_PCT   = '% of Clients Treated for Alc Abuse' 
   D_PCT   = '% of Clients Treated for Drug Abuse' 
   TOTADMIS= 'Total # of admissions for Sub Abuse Tx' 
   FACCLI  = 'Other facilities included in client ct' 
   FACNUM  = '# of Facilities in Client Count Data' 
   ACTHI   = 'Actual or estimate hosp inpat''nt client ct' 
   ACTRES  = 'Actual or estimate non-hosp res client ct' 
   ACTOP   = 'Actual or estimate outpat''nt client ct' 
   TOTADEST= 'Actual or Estimate admis no.' 
   LICENSED= 'Licns''d/certif''d by State SA Agency' 
   LICENMH = 'Licns''d/certif''d by Mental Health Dept.' 
   LICENPH = 'Licns''d/certif''d by Public Health Dept.' 
   LICENHOS= 'Licns''d/certif''d by Hospital authority' 
   JCAHO   = 'Accredt''d by JCAHO' 
   CARF    = 'Accredt''d by CARF' 
   NCQA    = 'Accredt''d by NCQA' 
   COA     = 'Accredt''d by COA' 
   OTHSTATE= 'Licns''d/certif''d by other State Agency' 
   INTERNET= 'Has internet access' 
   HASWEB  = 'Has Web site- y/n' 
   RPTLVL  = 'Added: Reporting for Self, Self & Others, No Counts' 
   T_CLI11 = 'Added: Total t_cli11 3/29/03' 
   T_CLIJUV= 'Added: Total t_cli11 Under Age 18 3/29/03' 
   T_CLIMET= 'Added: Total Methadone/LAAM Detox/Maint 3/29/03' 
   OWNRSPFL= 'Flag for OWNERSHP' 
   OTPFL   = 'Flag for OTP' 
   OTPTYPEF= 'Flag for OTPTYPE' 
   OTPALLFL= 'Flag for OTPALL' 
   LANGFL  = 'Flag for LANG' 
   OTHFAC2F= 'Flag for OTHFAC2' 
   OTHFAC1F= 'Flag for OTHFAC1' 
   TYPE4FL = 'Flag for TYPE4' 
   T_CLIHIF= 'Flag for Hospital Inpatient t_cli11' 
   HIMTLAMF= 'Flag for HI METH/LAAM edits and imputations' 
   HOSPBEDF= 'Flag for HOSPBED edits and imputations' 
   TYPE7FL = 'Flag for TYPE7' 
   T_CLIRCF= 'Flag for Residential t_cli11' 
   RCMTLAMF= 'Flag for RC METH/LAAM edits and imputations' 
   RESBEDFL= 'Flag for RESBED edits and imputations' 
   TYPE1FL = 'Flag for TYPE1' 
   T_CLIOPF= 'Flag for Outpatient t_cli11' 
   OPMTLAMF= 'Flag for OP METH/LAAM edits and imputations' 
   PCTFL   = 'Flag for A_PCT, B_PCT & D_PCT' 
   TOTADMFL= 'Flag for TOTADMIS edits and imputations' 
   FACNUMFL= 'Flag for FACNUM' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OTHNONTX <= -1) THEN OTHNONTX = .;
   IF (DETOX <= -1) THEN DETOX = .;
   IF (TREATMT <= -1) THEN TREATMT = .;
   IF (LOC5 <= -1) THEN LOC5 = .;
   IF (ADMIN <= -1) THEN ADMIN = .;
   IF (FOCUS <= -1) THEN FOCUS = .;
   IF (OWNERSHP <= -1) THEN OWNERSHP = .;
   IF (FEDOWN <= -1) THEN FEDOWN = .;
   IF (LOC15 <= -1) THEN LOC15 = .;
   IF (RELIG <= -1) THEN RELIG = .;
   IF (HOSPITAL <= -1) THEN HOSPITAL = .;
   IF (LOCS <= -1) THEN LOCS = .;
   IF (HOTYN <= -1) THEN HOTYN = .;
   IF (SRVC1 <= -1) THEN SRVC1 = .;
   IF (SRVC2 <= -1) THEN SRVC2 = .;
   IF (SRVC4 <= -1) THEN SRVC4 = .;
   IF (SRVC5 <= -1) THEN SRVC5 = .;
   IF (SRVC6 <= -1) THEN SRVC6 = .;
   IF (SRVC8 <= -1) THEN SRVC8 = .;
   IF (SRVC27 <= -1) THEN SRVC27 = .;
   IF (SRVC70 <= -1) THEN SRVC70 = .;
   IF (SRVC71 <= -1) THEN SRVC71 = .;
   IF (SRVC72 <= -1) THEN SRVC72 = .;
   IF (SRVC10 <= -1) THEN SRVC10 = .;
   IF (SRVC11 <= -1) THEN SRVC11 = .;
   IF (SRVC73 <= -1) THEN SRVC73 = .;
   IF (SRVC74 <= -1) THEN SRVC74 = .;
   IF (SRVC14 <= -1) THEN SRVC14 = .;
   IF (SRVC15 <= -1) THEN SRVC15 = .;
   IF (SRVC16 <= -1) THEN SRVC16 = .;
   IF (SRVC36 <= -1) THEN SRVC36 = .;
   IF (SRVC37 <= -1) THEN SRVC37 = .;
   IF (SRVC38 <= -1) THEN SRVC38 = .;
   IF (SRVC39 <= -1) THEN SRVC39 = .;
   IF (SRVC49 <= -1) THEN SRVC49 = .;
   IF (SRVC50 <= -1) THEN SRVC50 = .;
   IF (SRVC52 <= -1) THEN SRVC52 = .;
   IF (SRVC24 <= -1) THEN SRVC24 = .;
   IF (SRVC55 <= -1) THEN SRVC55 = .;
   IF (SRVC59 <= -1) THEN SRVC59 = .;
   IF (SRVC48 <= -1) THEN SRVC48 = .;
   IF (SRVC75 <= -1) THEN SRVC75 = .;
   IF (OTP <= -1) THEN OTP = .;
   IF (OTPTYPE <= -1) THEN OTPTYPE = .;
   IF (OTPALL <= -1) THEN OTPALL = .;
   IF (DUI_DWI <= -1) THEN DUI_DWI = .;
   IF (ONLYDUI <= -1) THEN ONLYDUI = .;
   IF (SIGNLANG <= -1) THEN SIGNLANG = .;
   IF (LANG <= -1) THEN LANG = .;
   IF (LANG1 <= -1) THEN LANG1 = .;
   IF (LANG2 <= -1) THEN LANG2 = .;
   IF (LANG3 <= -1) THEN LANG3 = .;
   IF (LANG4 <= -1) THEN LANG4 = .;
   IF (LANG5 <= -1) THEN LANG5 = .;
   IF (LANG6 <= -1) THEN LANG6 = .;
   IF (LANG7 <= -1) THEN LANG7 = .;
   IF (LANG8 <= -1) THEN LANG8 = .;
   IF (LANG9 <= -1) THEN LANG9 = .;
   IF (LANG10 <= -1) THEN LANG10 = .;
   IF (LANG11 <= -1) THEN LANG11 = .;
   IF (LANG12 <= -1) THEN LANG12 = .;
   IF (LANG13 <= -1) THEN LANG13 = .;
   IF (LANG14 <= -1) THEN LANG14 = .;
   IF (LANG15 <= -1) THEN LANG15 = .;
   IF (LANG16 <= -1) THEN LANG16 = .;
   IF (LANG17 <= -1) THEN LANG17 = .;
   IF (LANG18 <= -1) THEN LANG18 = .;
   IF (SRVC76 <= -1) THEN SRVC76 = .;
   IF (SRVC30 <= -1) THEN SRVC30 = .;
   IF (SRVC77 <= -1) THEN SRVC77 = .;
   IF (SRVC31 <= -1) THEN SRVC31 = .;
   IF (SRVC78 <= -1) THEN SRVC78 = .;
   IF (SRVC61 <= -1) THEN SRVC61 = .;
   IF (SRVC79 <= -1) THEN SRVC79 = .;
   IF (SRVC32 <= -1) THEN SRVC32 = .;
   IF (SRVC80 <= -1) THEN SRVC80 = .;
   IF (SRVC62 <= -1) THEN SRVC62 = .;
   IF (SRVC81 <= -1) THEN SRVC81 = .;
   IF (SRVC63 <= -1) THEN SRVC63 = .;
   IF (SRVC82 <= -1) THEN SRVC82 = .;
   IF (SRVC33 <= -1) THEN SRVC33 = .;
   IF (SRVC83 <= -1) THEN SRVC83 = .;
   IF (SRVC34 <= -1) THEN SRVC34 = .;
   IF (SRVC84 <= -1) THEN SRVC84 = .;
   IF (SRVC64 <= -1) THEN SRVC64 = .;
   IF (SRVC35 <= -1) THEN SRVC35 = .;
   IF (CTYPE4 <= -1) THEN CTYPE4 = .;
   IF (CTYPEHI1 <= -1) THEN CTYPEHI1 = .;
   IF (CTYPEHI2 <= -1) THEN CTYPEHI2 = .;
   IF (CTYPE7 <= -1) THEN CTYPE7 = .;
   IF (CTYPERC1 <= -1) THEN CTYPERC1 = .;
   IF (CTYPERC3 <= -1) THEN CTYPERC3 = .;
   IF (CTYPERC4 <= -1) THEN CTYPERC4 = .;
   IF (CTYPE1 <= -1) THEN CTYPE1 = .;
   IF (CTYPE6 <= -1) THEN CTYPE6 = .;
   IF (CTYPEML <= -1) THEN CTYPEML = .;
   IF (CTYPEOP <= -1) THEN CTYPEOP = .;
   IF (CTYPE2 <= -1) THEN CTYPE2 = .;
   IF (CTYPE3 <= -1) THEN CTYPE3 = .;
   IF (FEESCALE <= -1) THEN FEESCALE = .;
   IF (PAYASST <= -1) THEN PAYASST = .;
   IF (REVCHK1 <= -1) THEN REVCHK1 = .;
   IF (REVCHK8 <= -1) THEN REVCHK8 = .;
   IF (REVCHK5 <= -1) THEN REVCHK5 = .;
   IF (REVCHK10 <= -1) THEN REVCHK10 = .;
   IF (REVCHK15 <= -1) THEN REVCHK15 = .;
   IF (REVCHK2 <= -1) THEN REVCHK2 = .;
   IF (REVCHK3 <= -1) THEN REVCHK3 = .;
   IF (REVCHK2A <= -1) THEN REVCHK2A = .;
   IF (EARMARK <= -1) THEN EARMARK = .;
   IF (WRITARRA <= -1) THEN WRITARRA = .;
   IF (SAT <= -1) THEN SAT = .;
   IF (OTHFAC2 <= -1) THEN OTHFAC2 = .;
   IF (OTHFAC1 <= -1) THEN OTHFAC1 = .;
   IF (OTHFAC3 <= -1) THEN OTHFAC3 = .;
   IF (TYPE4 <= -1) THEN TYPE4 = .;
   IF (T_CLI1 <= -1) THEN T_CLI1 = .;
   IF (T_CLI2 <= -1) THEN T_CLI2 = .;
   IF (T_CLIHI <= -1) THEN T_CLIHI = .;
   IF (H_AGE1 <= -1) THEN H_AGE1 = .;
   IF (HIMETNUM <= -1) THEN HIMETNUM = .;
   IF (HILAMNUM <= -1) THEN HILAMNUM = .;
   IF (HOSPBED <= -1) THEN HOSPBED = .;
   IF (TYPE7 <= -1) THEN TYPE7 = .;
   IF (T_CLI3 <= -1) THEN T_CLI3 = .;
   IF (T_CLI9 <= -1) THEN T_CLI9 = .;
   IF (T_CLI10 <= -1) THEN T_CLI10 = .;
   IF (T_CLIRC <= -1) THEN T_CLIRC = .;
   IF (R_AGE1 <= -1) THEN R_AGE1 = .;
   IF (RCMETNUM <= -1) THEN RCMETNUM = .;
   IF (RCLAMNUM <= -1) THEN RCLAMNUM = .;
   IF (RESBED <= -1) THEN RESBED = .;
   IF (TYPE1 <= -1) THEN TYPE1 = .;
   IF (T_CLI7 <= -1) THEN T_CLI7 = .;
   IF (T_CLIML <= -1) THEN T_CLIML = .;
   IF (T_CLI8 <= -1) THEN T_CLI8 = .;
   IF (T_CLI6 <= -1) THEN T_CLI6 = .;
   IF (T_CLI5 <= -1) THEN T_CLI5 = .;
   IF (T_CLIOP <= -1) THEN T_CLIOP = .;
   IF (O_AGE1 <= -1) THEN O_AGE1 = .;
   IF (OPMETNUM <= -1) THEN OPMETNUM = .;
   IF (OPLAMNUM <= -1) THEN OPLAMNUM = .;
   IF (B_PCT <= -1) THEN B_PCT = .;
   IF (A_PCT <= -1) THEN A_PCT = .;
   IF (D_PCT <= -1) THEN D_PCT = .;
   IF (TOTADMIS <= -1) THEN TOTADMIS = .;
   IF (FACCLI <= -1) THEN FACCLI = .;
   IF (FACNUM <= -1) THEN FACNUM = .;
   IF (ACTHI <= -1) THEN ACTHI = .;
   IF (ACTRES <= -1) THEN ACTRES = .;
   IF (ACTOP <= -1) THEN ACTOP = .;
   IF (TOTADEST <= -1) THEN TOTADEST = .;
   IF (LICENSED <= -1) THEN LICENSED = .;
   IF (LICENMH <= -1) THEN LICENMH = .;
   IF (LICENPH <= -1) THEN LICENPH = .;
   IF (LICENHOS <= -1) THEN LICENHOS = .;
   IF (JCAHO <= -1) THEN JCAHO = .;
   IF (CARF <= -1) THEN CARF = .;
   IF (NCQA <= -1) THEN NCQA = .;
   IF (COA <= -1) THEN COA = .;
   IF (OTHSTATE <= -1) THEN OTHSTATE = .;
   IF (INTERNET <= -1) THEN INTERNET = .;
   IF (HASWEB <= -1) THEN HASWEB = .;
   IF (RPTLVL <= -1) THEN RPTLVL = .;
   IF (T_CLI11 <= -1) THEN T_CLI11 = .;
   IF (T_CLIJUV <= -1) THEN T_CLIJUV = .;
   IF (T_CLIMET <= -1) THEN T_CLIMET = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT MODE mode. STFIPS stfips. REGION region.
         DIVISION division. OTHNONTX othnontx. DETOX detox.
         TREATMT treatmt. LOC5 loc5ffff. ADMIN admin.
         FOCUS focus. OWNERSHP ownershp. FEDOWN fedown.
         LOC15 loc15fff. RELIG relig. HOSPITAL hospital.
         LOCS locs. HOTYN hotyn. SRVC1 srvc1fff.
         SRVC2 srvc2fff. SRVC4 srvc4fff. SRVC5 srvc5fff.
         SRVC6 srvc6fff. SRVC8 srvc8fff. SRVC27 srvc27ff.
         SRVC70 srvc70ff. SRVC71 srvc71ff. SRVC72 srvc72ff.
         SRVC10 srvc10ff. SRVC11 srvc11ff. SRVC73 srvc73ff.
         SRVC74 srvc74ff. SRVC14 srvc14ff. SRVC15 srvc15ff.
         SRVC16 srvc16ff. SRVC36 srvc36ff. SRVC37 srvc37ff.
         SRVC38 srvc38ff. SRVC39 srvc39ff. SRVC49 srvc49ff.
         SRVC50 srvc50ff. SRVC52 srvc52ff. SRVC24 srvc24ff.
         SRVC55 srvc55ff. SRVC59 srvc59ff. SRVC48 srvc48ff.
         SRVC75 srvc75ff. OTP otp. OTPTYPE otptype.
         OTPALL otpall. DUI_DWI dui_dwi. ONLYDUI onlydui.
         SIGNLANG signlang. LANG lang. LANG1 lang1fff.
         LANG2 lang2fff. LANG3 lang3fff. LANG4 lang4fff.
         LANG5 lang5fff. LANG6 lang6fff. LANG7 lang7fff.
         LANG8 lang8fff. LANG9 lang9fff. LANG10 lang10ff.
         LANG11 lang11ff. LANG12 lang12ff. LANG13 lang13ff.
         LANG14 lang14ff. LANG15 lang15ff. LANG16 lang16ff.
         LANG17 lang17ff. LANG18 lang18ff. SRVC76 srvc76ff.
         SRVC30 srvc30ff. SRVC77 srvc77ff. SRVC31 srvc31ff.
         SRVC78 srvc78ff. SRVC61 srvc61ff. SRVC79 srvc79ff.
         SRVC32 srvc32ff. SRVC80 srvc80ff. SRVC62 srvc62ff.
         SRVC81 srvc81ff. SRVC63 srvc63ff. SRVC82 srvc82ff.
         SRVC33 srvc33ff. SRVC83 srvc83ff. SRVC34 srvc34ff.
         SRVC84 srvc84ff. SRVC64 srvc64ff. SRVC35 srvc35ff.
         CTYPE4 ctype4ff. CTYPEHI1 ctypehif. CTYPEHI2 ctypeh0f.
         CTYPE7 ctype7ff. CTYPERC1 ctypercf. CTYPERC3 ctyper0f.
         CTYPERC4 ctyper1f. CTYPE1 ctype1ff. CTYPE6 ctype6ff.
         CTYPEML ctypeml. CTYPEOP ctypeop. CTYPE2 ctype2ff.
         CTYPE3 ctype3ff. FEESCALE feescale. PAYASST payasst.
         REVCHK1 revchk1f. REVCHK8 revchk8f. REVCHK5 revchk5f.
         REVCHK10 revchk0f. REVCHK15 revchk2f. REVCHK2 revchk3f.
         REVCHK3 revchk4f. REVCHK2A revchk2a. EARMARK earmark.
         WRITARRA writarra. SAT sat. OTHFAC2 othfac2f.
         OTHFAC1 othfac1f. OTHFAC3 othfac3f. TYPE4 type4fff.
         T_CLI1 t_cli1ff. T_CLI2 t_cli2ff. T_CLIHI t_clihi.
         H_AGE1 h_age1ff. HIMETNUM himetnum. HILAMNUM hilamnum.
         HOSPBED hospbed. TYPE7 type7fff. T_CLI3 t_cli3ff.
         T_CLI9 t_cli9ff. T_CLI10 t_cli10f. T_CLIRC t_clirc.
         R_AGE1 r_age1ff. RCMETNUM rcmetnum. RCLAMNUM rclamnum.
         RESBED resbed. TYPE1 type1fff. T_CLI7 t_cli7ff.
         T_CLIML t_climl. T_CLI8 t_cli8ff. T_CLI6 t_cli6ff.
         T_CLI5 t_cli5ff. T_CLIOP t_cliop. O_AGE1 o_age1ff.
         OPMETNUM opmetnum. OPLAMNUM oplamnum. B_PCT b_pct.
         A_PCT a_pct. D_PCT d_pct. TOTADMIS totadmis.
         FACCLI faccli. FACNUM facnum. ACTHI acthi.
         ACTRES actres. ACTOP actop. TOTADEST totadest.
         LICENSED licensed. LICENMH licenmh. LICENPH licenph.
         LICENHOS licenhos. JCAHO jcaho. CARF carf.
         NCQA ncqa. COA coa. OTHSTATE othstate.
         INTERNET internet. HASWEB hasweb. RPTLVL rptlvl.
         T_CLI11 t_cli11f. T_CLIJUV t_clijuv. T_CLIMET t_climet.
         OWNRSPFL ownrspfl. OTPFL otpfl. OTPTYPEF otptypef.
         OTPALLFL otpallfl. LANGFL langfl. OTHFAC2F othfac0f.
         OTHFAC1F othfac4f. TYPE4FL type4fl. T_CLIHIF t_clihif.
         HIMTLAMF himtlamf. HOSPBEDF hospbedf. TYPE7FL type7fl.
         T_CLIRCF t_clircf. RCMTLAMF rcmtlamf. RESBEDFL resbedfl.
         TYPE1FL type1fl. T_CLIOPF t_cliopf. OPMTLAMF opmtlamf.
         PCTFL pctfl. TOTADMFL totadmfl. FACNUMFL facnumfl.
          ;
*/

RUN ;
